@@ -24,6 +24,7 @@ import mock
 import six
 import suds
 
+from oslo_context import context
 from oslo_vmware import api
 from oslo_vmware import exceptions
 from oslo_vmware import pbm
@@ -393,7 +394,10 @@ class VMwareAPISessionTest(base.TestCase):
                                'api')
         self.assertEqual(fault_list, ex.fault_list)
 
-    def test_wait_for_task(self):
+    @mock.patch.object(context, 'get_current')
+    def test_wait_for_task(self, mock_curr_ctx):
+        ctx = mock.Mock()
+        mock_curr_ctx.return_value = ctx
         api_session = self._create_api_session(True)
         task_info_list = [('queued', 0), ('running', 40), ('success', 100)]
         task_info_list_size = len(task_info_list)
@@ -420,8 +424,41 @@ class VMwareAPISessionTest(base.TestCase):
                                                   skip_op_id=True)
         self.assertEqual(task_info_list_size,
                          api_session.invoke_api.call_count)
+        mock_curr_ctx.assert_called_once()
+        self.assertEqual(3, ctx.update_store.call_count)
 
-    def test_wait_for_task_with_error_state(self):
+    @mock.patch.object(context, 'get_current', return_value=None)
+    def test_wait_for_task_no_ctx(self, mock_curr_ctx):
+        api_session = self._create_api_session(True)
+        task_info_list = [('queued', 0), ('running', 40), ('success', 100)]
+        task_info_list_size = len(task_info_list)
+
+        def invoke_api_side_effect(module, method, *args, **kwargs):
+            (state, progress) = task_info_list.pop(0)
+            task_info = mock.Mock()
+            task_info.progress = progress
+            task_info.queueTime = datetime(2016, 12, 6, 15, 29, 43, 79060)
+            task_info.completeTime = datetime(2016, 12, 6, 15, 29, 50, 79060)
+            task_info.state = state
+            return task_info
+
+        api_session.invoke_api = mock.Mock(side_effect=invoke_api_side_effect)
+        task = mock.Mock()
+        with mock.patch.object(greenthread, 'sleep'):
+            ret = api_session.wait_for_task(task)
+            self.assertEqual('success', ret.state)
+            self.assertEqual(100, ret.progress)
+        api_session.invoke_api.assert_called_with(vim_util,
+                                                  'get_object_property',
+                                                  api_session.vim, task,
+                                                  'info',
+                                                  skip_op_id=True)
+        self.assertEqual(task_info_list_size,
+                         api_session.invoke_api.call_count)
+        mock_curr_ctx.assert_called_once()
+
+    @mock.patch.object(context, 'get_current')
+    def test_wait_for_task_with_error_state(self, mock_curr_ctx):
         api_session = self._create_api_session(True)
         task_info_list = [('queued', 0), ('running', 40), ('error', -1)]
         task_info_list_size = len(task_info_list)
@@ -446,8 +483,10 @@ class VMwareAPISessionTest(base.TestCase):
                                                   skip_op_id=True)
         self.assertEqual(task_info_list_size,
                          api_session.invoke_api.call_count)
+        mock_curr_ctx.assert_called_once()
 
-    def test_wait_for_task_with_invoke_api_exception(self):
+    @mock.patch.object(context, 'get_current')
+    def test_wait_for_task_with_invoke_api_exception(self, mock_curr_ctx):
         api_session = self._create_api_session(True)
         api_session.invoke_api = mock.Mock(
             side_effect=exceptions.VimException(None))
@@ -461,6 +500,7 @@ class VMwareAPISessionTest(base.TestCase):
                                                        api_session.vim, task,
                                                        'info',
                                                        skip_op_id=True)
+        mock_curr_ctx.assert_called_once()
 
     def test_wait_for_lease_ready(self):
         api_session = self._create_api_session(True)
@@ -551,9 +591,11 @@ class VMwareAPISessionTest(base.TestCase):
         ):
             fake_task = mock.Mock()
             fake_task.value = 'task-1'
+            ctx = mock.Mock()
             self.assertRaises(expected_exception,
                               api_session._poll_task,
-                              fake_task)
+                              fake_task,
+                              ctx)
 
     def test_poll_task_well_known_exceptions(self):
         for k, v in six.iteritems(exceptions._fault_classes_registry):
